@@ -28,14 +28,14 @@ from typing import (
 )
 
 __all__ = [
-    "to_snake_case",
-    "to_camel_case",
+    "CamelSnakeMixin",
+    "ValidateMixin",
+    "as_dict",
     "as_json",
     "from_dict",
     "from_json",
-    "as_dict",
-    "ValidateMixin",
-    "CamelSnakeMixin",
+    "to_camel_case",
+    "to_snake_case",
 ]
 
 _RE_SNAKE_CASE_1 = re.compile(r"[\-\.\s]")
@@ -190,6 +190,7 @@ def as_json(obj: Any, indent: Optional[bool] = None, compact: Optional[bool] = N
         default=_default,
         indent=4 if indent else None,
         separators=(",", ":") if compact else None,
+        ensure_ascii=False,
     )
 
 
@@ -242,6 +243,8 @@ def add_type_signature_to_cache(t: Type[Any]) -> None:
 def _get_signature_cached(t: Type[Any]) -> inspect.Signature:
     r = __signature_cache.get(t, __NOT_SET)
     if r is __NOT_SET:
+        if t is bool:
+            raise ValueError
         r = __signature_cache[t] = inspect.signature(t)
     return cast(inspect.Signature, r)
 
@@ -314,7 +317,7 @@ def __from_dict_handle_basic_types(value: Any, t: Type[Any], strict: bool) -> Tu
 
 
 def __from_dict_handle_sequence(value: Any, t: Type[Any], strict: bool) -> Tuple[Any, bool]:
-    if isinstance(value, Sequence):
+    if isinstance(value, Sequence) and not isinstance(value, str):
         args = _get_args_cached(t)
         return (_get_origin_cached(t) or t)(from_dict(v, args, strict=strict) for v in value), True
     return None, False
@@ -416,6 +419,9 @@ def from_dict(
         match_type_hints: Optional[Dict[str, Any]] = None
 
         for t in types:
+            if t is type(None):
+                continue
+
             origin = _get_origin_cached(t)
 
             if origin is Literal:
@@ -452,7 +458,7 @@ def from_dict(
                 match_type_hints = type_hints
             elif match_same_keys is not None and len(match_same_keys) == len(same_keys):
                 raise TypeError(
-                    f"Value {value!r} matches to more then one types of "
+                    f"Value {value!r} of type {type(value)!r} matches to more then one types of "
                     f"{repr(types[0].__name__) if len(types) == 1 else ' | '.join(repr(e.__name__) for e in types)}."
                 )
 
@@ -471,7 +477,7 @@ def from_dict(
             try:
                 return match_(**params)
             except TypeError as ex:
-                raise TypeError(f"Can't initialize class {match_!r} with parameters {params!r}: {ex}") from ex
+                raise TypeError(f"Can't initialize {match_!r} with parameters {params!r}: {ex}") from ex
 
     raise TypeError(
         "Value must be of type `"
@@ -639,7 +645,7 @@ def validate_types(expected_types: Union[type, Tuple[type, ...], None], value: A
             continue
 
         if (
-            t is Any
+            t is Any  # type: ignore
             or t is Ellipsis  # type: ignore
             or isinstance(value, origin or t)
             or (
@@ -675,7 +681,7 @@ def validate_types(expected_types: Union[type, Tuple[type, ...], None], value: A
 
                 return []
 
-            if t is Any:
+            if t is Any:  # type: ignore
                 return []
 
             if isinstance(value, origin or t):
@@ -698,7 +704,7 @@ class ValidateMixin:
         if not dataclasses.is_dataclass(self):
             return
 
-        for f in dataclasses.fields(self):
+        for f in dataclasses.fields(self):  # type: ignore
             converter = f.metadata.get("convert")
             if converter is not None:
                 if inspect.ismethod(converter):
@@ -710,7 +716,7 @@ class ValidateMixin:
         if not dataclasses.is_dataclass(self):
             return
 
-        errors = {}
+        errors = {}  # type: ignore
 
         type_hints = _get_type_hints_cached(type(self))
 
